@@ -13,6 +13,10 @@
 #include "config.h"
 #endif
 
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
+
 #include <gnome.h>
 #include <gdk/gdkx.h>
 #include <glib/gi18n.h>
@@ -232,6 +236,15 @@ static void
 set_icon (GtkImage *image, GtkIconTheme *theme, const char *name)
 {
 	GdkPixbuf *pixbuf;
+	struct stat st;
+	
+	if (*name == '/') {
+		if (stat (name, &st) == 0 && S_ISREG (st.st_mode)) {
+			gtk_image_set_from_file (image, name);
+			return;
+		} else
+			name = "gnome-dev-broken-image";
+	}
 	
 	if ((pixbuf = gtk_icon_theme_load_icon (theme, name, 48, 0, NULL))) {
 		gtk_image_set_from_pixbuf (image, pixbuf);
@@ -257,7 +270,7 @@ static struct {
 	{ "removable_drives_image", "gnome-dev-removable"     },
 	{ "scanner_image",          "xsane"                   },
 	/* FIXME: need better icon */
-	{ "tablet_image",           "gnome-dev-mouse-optical" },
+	{ "tablet_image",           ICONSDIR "/gvm-dev-tablet.png" },
 	/* FIXME: need better icon */
 	{ "videocam_image",         "gnome-mime-video"        }
 };
